import file_ripper.fileconstants as file_constants
from file_ripper.filedefinition import FileDefinition, FieldDefinition
from file_ripper.fileripper import rip_file, rip_files, find_and_rip_files
from file_ripper.commands import run_file_ripper_once, run_file_ripper_continuously

__all__ = [
    "file_constants",
    "FileDefinition",
    "FieldDefinition",
    "rip_files",
    "rip_file",
    "find_and_rip_files",
    "run_file_ripper_continuously",
    "run_file_ripper_once",
]



from time import sleep


def run_file_ripper_once(definitions_file, definitions_format):
    print("running file ripper")


def run_file_ripper_continuously(definitions_file, definitions_format, interval_minutes=5):
    while True:
        run_file_ripper_once(definitions_file, definitions_format)
        sleep(60 * interval_minutes)
